@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious';
 
 use Data::Dumper;
 
-our $VERSION = '0.013';
+our $VERSION = '0.015';
 
 use File::Basename 'dirname';
 use File::Spec;
@@ -190,7 +190,11 @@ AproJo - A time recording application based on Mojolicious
 
 =head1 DESCRIPTION
 
-L<AproJo> is a Perl web apllication.
+L<AproJo> is a Perl web application.
+
+=head1 STATUS
+
+L<AproJo> is still in pre-Alpha state. It still misses essential features to be useful in production.
 
 =head1 INSTALLATION
 
@@ -289,7 +293,7 @@ L<Contenticious> - File-based Markdown website application
 
 =head1 SOURCE REPOSITORY
 
-L<http://github.com/wollmers/aprojo>
+L<http://github.com/wollmers/AproJo>
 
 =head1 AUTHOR
 
